@@ -36,8 +36,6 @@ def main():
                         help='when linearising kpoint path, ensure distance in reciprocal space is conserved')
     parser.add_argument('--cmap', type=str,
                         help='matplotlib colourmap name to use')
-    parser.add_argument('--n_colours', type=int,
-                        help='number of colours to use from colourmap (DEFAULT: 6)')
     parser.add_argument('--spin_only', type=str,
                         help='either "up" or "down" to only plot one channel')
     parser.add_argument('-interp', '--pdis_interpolation_factor', type=float,
@@ -55,9 +53,12 @@ def main():
                         help='try to reorder bands based on local gradients')
     parser.add_argument('--pdos_hide_sum', action='store_true',
                         help='plot PDOS without sum pDOS')
-    parser.add_argument('--band_colour', type=str,
-                        help='override all other colour options with a matploblib-interpretable colour string, '
-                             'or choose one of "occ" or "random".')
+    parser.add_argument('--projector_colours', type=str, nargs="+",
+                        help='override all projector colour options with a list of matplotlib-interpretable colours, '
+                             'e.g. --projector_colours red blue #ff00ff')
+    parser.add_argument('--colours', type=str, nargs="+",
+                        help='override all colour options with a list of matplotlib-interpretable colours, '
+                             'e.g. --colours red blue #ff00ff')
     parser.add_argument('-g', '--gap', action='store_true',
                         help='plot position and size of band gap')
     parser.add_argument('-ph', '--phonons', action='store_true', default=False,
@@ -108,7 +109,6 @@ def main():
     del kwargs['no_pdis']
 
     cmap = kwargs.get('cmap')
-    band_colour = kwargs.get('band_colour', 'occ')
     band_reorder = kwargs.get('band_reorder', False)
 
     from matador.plotting import plot_spectral, plot_ir_spectrum
@@ -117,7 +117,6 @@ def main():
     del kwargs['verbosity']
     del kwargs['labels']
     del kwargs['cmap']
-    del kwargs['band_colour']
     del kwargs['band_reorder']
 
     bandstructure = False
@@ -170,7 +169,6 @@ def main():
             labels=labels,
             cmap=cmap,
             band_reorder=band_reorder,
-            band_colour=band_colour,
             **kwargs
         )
 
