@@ -558,7 +558,7 @@ def get_root_source(source):
     """ Get the main file source from a doc's source list.
 
     Parameters:
-        source (list/dict): contents of doc['source'] or the doc itself.
+        source (str/list/dict): contents of doc['source'] or the doc itself.
 
     Returns:
         str: "root" filename, e.g. if source = ['KP.cell', 'KP.param',
@@ -570,6 +570,9 @@ def get_root_source(source):
     except (KeyError, TypeError):
         sources = copy.deepcopy(source)
 
+    if isinstance(source, str):
+        return source
+
     src_list = set()
     for src in sources:
         if any([src.endswith(ext) for ext in
